@@ -4,32 +4,38 @@
 #' in a single row header of a flextable.
 #'
 #' @param x a \code{flextable} object
-#' @param ... a named list (names are data colnames), each element is a single character
+#' @param ... named arguments (names are data colnames), each element is a single character
 #' value specifying label to use.
+#' @param values a named list (names are data colnames), each element is a single character
+#' value specifying label to use. If provided, argument \code{...} will be ignored.
 #' @examples
 #' ft_1 <- flextable( head( iris ))
 #' ft_1 <- set_header_labels(ft_1, Sepal.Length = "Sepal length",
 #'   Sepal.Width = "Sepal width", Petal.Length = "Petal length",
 #'   Petal.Width = "Petal width"
 #' )
-#' ft_1
+#'
+#' ft_2 <- flextable( head( iris ))
+#' ft_2 <- set_header_labels(ft_2,
+#'   values = list(Sepal.Length = "Sepal length",
+#'                 Sepal.Width = "Sepal width",
+#'                 Petal.Length = "Petal length",
+#'                 Petal.Width = "Petal width" ) )
+#' ft_2
 #' @export
-set_header_labels <- function(x, ...){
+set_header_labels <- function(x, ..., values = NULL){
 
   if( !inherits(x, "flextable") ) stop("set_header_labels supports only flextable objects.")
 
-  args <- list(...)
-  if( nrow(x$header$dataset) < 1 )
-    stop("there is no header row to be replaced")
+  if( is.null(values)){
+    values <- list(...)
+    if( nrow_part(x, "header") < 1 )
+      stop("there is no header row to be replaced")
 
-  header_ <- x$header$dataset
+  }
 
-  values <- as.list(tail(x$header$dataset, n = 1))
-  args <- args[is.element(names(args), x$col_keys)]
-  values[names(args)] <- args
+  x$header$content[nrow_part(x, "header"), names(values)] <- as_paragraph(as_chunk(unlist(values)))
 
-  x$header$dataset <- rbind( header_[-nrow(header_),],
-                             as.data.frame(values, stringsAsFactors = FALSE, check.names = FALSE ))
   x
 }
 
@@ -47,7 +53,7 @@ set_header_labels <- function(x, ...){
 #' ft <- delete_part(x = ft, part = "header")
 #' ft
 delete_part <- function(x, part = "header"){
-  if( !inherits(x, "flextable") ) stop("set_header_labels supports only flextable objects.")
+  if( !inherits(x, "flextable") ) stop("delete_part supports only flextable objects.")
   part <- match.arg(part, c("body", "header", "footer"), several.ok = FALSE )
   nrow_ <- nrow(x[[part]]$dataset)
   x[[part]]$dataset <- x[[part]]$dataset[-seq_len(nrow_),, drop = FALSE]
@@ -83,7 +89,7 @@ delete_part <- function(x, part = "header"){
 #' @name add_header_footer
 add_header <- function(x, top = TRUE, ...){
 
-  if( !inherits(x, "flextable") ) stop("set_header_labels supports only flextable objects.")
+  if( !inherits(x, "flextable") ) stop("add_header supports only flextable objects.")
   args <- list(...)
   args_ <- lapply(x$col_keys, function(x) "" )
   names(args_) <- x$col_keys
@@ -98,7 +104,7 @@ add_header <- function(x, top = TRUE, ...){
 #' @export
 #' @rdname add_header_footer
 add_footer <- function(x, top = TRUE, ...){
-  if( !inherits(x, "flextable") ) stop("set_header_labels supports only flextable objects.")
+  if( !inherits(x, "flextable") ) stop("add_footer supports only flextable objects.")
   args <- list(...)
   args_ <- lapply(x$col_keys, function(x) "" )
   names(args_) <- x$col_keys
@@ -106,16 +112,7 @@ add_footer <- function(x, top = TRUE, ...){
   footer_data <- data.frame(as.list(args_), check.names = FALSE, stringsAsFactors = FALSE )
 
   if( nrow_part(x, "footer") < 1 ) {
-    if(inherits(x, "regulartable")){
-      x$footer <- simple_tabpart( data = footer_data, col_keys = x$col_keys,
-                                   cwidth = .75, cheight = .25 )
-    } else if(inherits(x, "complextable")){
-        x$footer <- complex_tabpart( data = footer_data, col_keys = x$col_keys,
-                                     cwidth = .75, cheight = .25 )
-    } else {
-      stop("add footer only supported for regulartable et complextable objects.", call. = FALSE)
-    }
-
+    x$footer <- complex_tabpart( data = footer_data, col_keys = x$col_keys, cwidth = .75, cheight = .25 )
   } else {
     x$footer <- add_rows( x$footer, footer_data, first = top )
   }
